containertools.replace_smaller_left_half_of_elements_in_container_with_little_endian_rests
==========================================================================================

.. autofunction:: abjad.tools.containertools.replace_smaller_left_half_of_elements_in_container_with_little_endian_rests.replace_smaller_left_half_of_elements_in_container_with_little_endian_rests
